
def test_something(a, b, c):
    """
    Test if something works, especially the documentation

    Parameters
    ----------
    a: str
    b: int

    Returns
    -------
    c: int
        Approximate answer to this advanced calculation.

    Notes
    -----
    Bladie bladie
    """

    return int(a) + int(b)